#
# spec file for package restic
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%define import_path github.com/restic/restic

Name:           restic
Version:        0.10.0
Release:        lp152.3.3.1
Summary:        Backup program with deduplication and encryption
License:        BSD-2-Clause
Group:          Productivity/Archiving/Backup
URL:            https://restic.net
Source0:        https://github.com/restic/restic/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/restic/restic/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        vendor.tar.xz
BuildRequires:  bash-completion
BuildRequires:  golang-packaging
BuildRequires:  zsh
BuildRequires:  golang(API) >= 1.13

%description
restic is a backup program. It supports verification, encryption,
snapshots and deduplication.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    packageand(restic:bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    packageand(restic:zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%setup -q -a 3

%build
# Set up GOPATH.
export GOPATH="$GOPATH:$HOME/go"
mkdir -p $HOME/go/src/%{import_path}
cp -rT $PWD $HOME/go/src/%{import_path}

# Build restic. We don't use build.go because it builds statically, uses go
# modules, and also restricts the Go version in cases where it's not actually
# necessary. We disable go modules because restic still provides a vendor/.
GO111MODULE=off go build -o %{name} -buildmode=pie \
	-ldflags "-s -w -X main.version=%{version}" \
	%{import_path}/cmd/restic

%install
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}
install -d %{buildroot}%{_mandir}/man1
./%{name} generate --man %{buildroot}%{_mandir}/man1
install -Dm0644 doc/bash-completion.sh %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm0644 doc/zsh-completion.zsh %{buildroot}%{_sysconfdir}/zsh_completion.d/%{name}

%files
%defattr(-,root,root)
%doc *.md *.rst
%doc doc/
%license LICENSE
%{_bindir}/restic
%{_mandir}/man1/restic*.1*

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files zsh-completion
%config %{_sysconfdir}/zsh_completion.d/%{name}

%changelog
* Tue Sep 22 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.10.0.
  https://github.com/restic/restic/releases/tag/v0.10.0
  See installed /usr/share/doc/packages/restic/CHANGELOG.md.
- we need to manually vendor the libraries now
- bump minimum go version to >= 1.13
* Sat Nov 23 2019 Aleksa Sarai <asarai@suse.com>
- Update to 0.9.6.
  https://github.com/restic/restic/releases/tag/v0.9.6
  See installed /usr/share/doc/packages/restic/CHANGELOG.md.
  Fixes:
  * Allow absolute path for filename when backing up from stdin
  * Save files with invalid timestamps
  * Read fresh metadata for unmodified files
  * Add upper bound for t in --read-data-subset=n/t
  * Check errors when loading index files
  Enhancements:
  + Allow multiple retries for interactive password input
  + Make --group-by accept both singular and plural
  + Add option to configure S3 region
* Tue Apr 23 2019 Aleksa Sarai <asarai@suse.com>
- Update to 0.9.5.
  https://github.com/restic/restic/releases/tag/v0.9.5
  See installed /usr/share/doc/packages/restic/CHANGELOG.md. Short-log:
  Fixes:
  * Return error when no bytes could be read from stdin
  * Don't cancel timeout after 30 seconds for self-update
  * Fix reading passwords from stdin
  * Don't abort the find command when a tree can't be loaded
  Enhancements:
  + Add case insensitive include & exclude options
  + Support streaming JSON output for backup
  + Add Openstack application credential auth for Swift
  + Add --json support to forget command
  + Add group-by option to snapshots command
  + Ability to dump folders to tar via stdout
  + Return error if no bytes could be read for backup --stdin
  + Add --ignore-inode option to backup cmd
  + Add config option to set S3 storage class
* Mon Jan  7 2019 Aleksa Sarai <asarai@suse.com>
- Update to 0.9.4.
  https://github.com/restic/restic/releases/tag/v0.9.4
  See installed /usr/share/doc/packages/restic/CHANGELOG.md
* Mon Nov  5 2018 Aleksa Sarai <asarai@suse.com>
- Update to 0.9.3. boo#1115498
  https://github.com/restic/restic/releases/tag/v0.9.3
  See installed /usr/share/doc/packages/restic/CHANGELOG.md
- Update to Go 1.9, and disable Go 1.11 modules since they require internet
  access (restic still provides vendor/).
* Wed Aug  8 2018 asarai@suse.com
- Update to 0.9.2.
  https://github.com/restic/restic/releases/tag/v0.9.2
  See installed /usr/share/doc/packages/restic/CHANGELOG.md
- Remove Go 1.8 compatibility patch, now that we have newer Go versions in
  older Leap releases.
  - restic-switch-to-pre-1.8-sort.Stable-API.patch
* Sat Jul 28 2018 jengelh@inai.de
- Substantiate program attribute claims in descriptions.
* Fri Jun 22 2018 asarai@suse.com
- Update to 0.9.1.
  https://github.com/restic/restic/releases/tag/v0.9.1
  See installed /usr/share/doc/packages/restic/CHANGELOG.md
- Switch to building with the new "go" metapkg.
- Switch to new %%license macro.
* Fri Jun 22 2018 asarai@suse.com
- Fix up restic-*-completion subpackages to use Supplements (to avoid
  installing shells on people's machines when they don't expect it).
* Thu Jun 21 2018 mardnh@gmx.de
- Add subpackages for command line completions for bash and
  zsh shells
* Thu Mar  1 2018 asarai@suse.com
- Update to 0.8.3.
  https://github.com/restic/restic/releases/tag/v0.8.3
  See installed /usr/share/doc/packages/restic/CHANGELOG.md
* Sat Jan 13 2018 asarai@suse.com
- Switch away from using build.go, and instead manually build with "go". This
  allows us to build with the older Go compilers present in Leap, as well as to
  build the binary as PIC and dynamic.
- Add generated man pages.
- In order to build with older Go compilers, add a patch.
  + restic-switch-to-pre-1.8-sort.Stable-API.patch
* Wed Jan 10 2018 asarai@suse.com
- Update to 0.8.1.
  https://github.com/restic/restic/releases/tag/v0.8.1
  See installed /usr/share/doc/packages/restic/CHANGELOG.md
* Wed Jan 10 2018 asarai@suse.com
- Add GPG verification of source as well as links to the source.
* Sun Dec 24 2017 mrueckert@suse.de
- Update to 0.8.0. This is a security release.
  https://github.com/restic/restic/releases/tag/v0.8.0
  See installed /usr/share/doc/packages/restic/CHANGELOG.md
* Thu Oct  5 2017 mrueckert@suse.de
- Update to 0.7.3.
  https://github.com/restic/restic/releases/tag/v0.7.3
  See installed /usr/share/doc/packages/restic/CHANGELOG.md
* Wed Aug 23 2017 mrueckert@suse.de
- should really be in _bindir of course
* Wed Aug 23 2017 mrueckert@suse.de
- update to package
